Crate jj_lib

Crate jj_lib 

Jujutsu version control system.

Modules

absorb
Algorithm to split changes in a single source commit into its most relevant ancestors, ‘absorbing’ them away.
annotate
Methods that allow annotation (attribution and blame) for a file in a repository.
backend
Defines the commit backend trait and related types. This is the lowest-level trait for reading and writing commits, trees, files, etc.
bisect
Bisect a range of commits.
commit
commit_builder
config
Configuration store helpers.
conflict_labels
Labels for conflicted trees.
conflicts
content_hash
Portable, stable hashing suitable for identifying values
converge
Utility for solving divergence. See https://github.com/jj-vcs/jj/blob/main/docs/design/jj-converge-command.md for more details.
copies
Code for working with copies and renames.
dag_walk
General-purpose DAG algorithms.
dag_walk_async
General-purpose async DAG algorithms.
default_backend_factories
Provides the default backend factories, i.e. GitBackend (if the git feature is enabled), SimpleOpStore, LocalWorkingCopy, etc.
default_index
An on-disk index of the commits in a repository.
default_submodule_store
diff
diff_presentation
Utilities to present file diffs to the user
dsl_util
Domain-specific language helpers.
evolution
Utility for commit evolution history.
extensions_map
file_util
Contains file utilities which work in a cross-platform way.
files
fileset
Functional language for selecting a set of paths.
fix
API for transforming file content, for example to apply formatting, and propagate those changes across revisions.
fmt_util
Common formatting helpers
fsmonitor
Filesystem monitor tool interface.
git
git_backend
gitignore
gpg_signing
graph
graph_dominators
Generic implementation of the “closest common dominator” algorithm for directed graphs.
hex_util
Hex string helpers.
id_prefix
index
Interfaces for indexes of the commits in a repository.
iter_util
Iterator helpers.
local_working_copy
lock
matchers
Contains the Matcher trait which is used for matching against RepoPaths and guiding walks of directory trees.
merge
Generic data structures and algorithms for working with merges and diffs of values.
merged_tree
A lazily merged view of a set of trees.
merged_tree_builder
Helps build a new MergedTree from a base tree and overrides.
object_id
Identifiers for objects (commits, changes, trees, etc.), and utilities for parsing and matching identifier prefixes.
op_heads_store
op_store
op_walk
Utility for operation id resolution and traversal.
operation
protos
ref_name
Name types for commit references.
refs
repo
repo_path
A RepoPath is a path relative to the repo root. It uses forward slashes as directory separators regardless of platform. It is always valid UTF-8.
revset
rewrite
secure_config
A mechanism to access config files for a repo securely.
settings
signing
Generic APIs to work with cryptographic signatures created and verified by various backends.
simple_backend
simple_op_heads_store
simple_op_store
ssh_signing
stacked_table
A persistent table of fixed-size keys to variable-size values.
store
str_util
String helpers.
submodule_store
time_util
Provides support for parsing and matching date ranges.
trailer
Parsing trailers from commit messages.
transaction
tree
tree_builder
tree_merge
Merge trees by recursing into entries (subtrees, files)
ui_path
Utilities for converting between RepoPaths and plain strings as displayed to the user (e.g. relative to CWD).
union_find
This module implements a UnionFind<T> type which can be used to efficiently calculate disjoint sets for any data type.
view
working_copy
Defines the interface for the working copy. See LocalWorkingCopy for the default local-disk implementation.
workspace
workspace_store
Workspace store for managing workspace metadata.