pub enum BackendError {
InvalidHashLength {
expected: usize,
actual: usize,
object_type: String,
hash: String,
},
InvalidUtf8 {
object_type: String,
hash: String,
source: Utf8Error,
},
ObjectNotFound {
object_type: String,
hash: String,
source: Box<dyn Error + Send + Sync>,
},
ReadObject {
object_type: String,
hash: String,
source: Box<dyn Error + Send + Sync>,
},
ReadAccessDenied {
object_type: String,
hash: String,
source: Box<dyn Error + Send + Sync>,
},
ReadFile {
path: RepoPathBuf,
id: FileId,
source: Box<dyn Error + Send + Sync>,
},
WriteObject {
object_type: &'static str,
source: Box<dyn Error + Send + Sync>,
},
Other(Box<dyn Error + Send + Sync>),
Unsupported(String),
}Expand description
Commit-backend error that may occur after the backend is loaded.
Variants
InvalidHashLength
The caller attempted to read an object by specifying an ID with an invalid hash length for this backend.
Fields
InvalidUtf8
The caller attempted to read an object that internally stored as invalid UTF-8, such as a symlink target with invalid UTF-8 stored in the Git backend.
Fields
ObjectNotFound
The caller attempted to read an object that doesn’t exist.
Fields
ReadObject
Failed to read an object due to an I/O error or other unexpected error.
Fields
ReadAccessDenied
The caller attempted to read an object but doesn’t have permission to read it.
Fields
ReadFile
Failed to read a file’s content due to an I/O error or other unexpected error.
Fields
path: RepoPathBufThe path of the file we failed to read.
WriteObject
Failed to write an object due to an I/O error or other unexpected error.
Fields
Other(Box<dyn Error + Send + Sync>)
Some other error that doesn’t fit into the above categories.
Unsupported(String)
A valid operation was attempted, but it failed because it isn’t supported by the particular backend.