Commit

Struct Commit 

pub struct Commit {
    pub parents: Vec<CommitId>,
    pub predecessors: Vec<CommitId>,
    pub root_tree: Merge<TreeId>,
    pub conflict_labels: Merge<String>,
    pub change_id: ChangeId,
    pub description: String,
    pub author: Signature,
    pub committer: Signature,
    pub secure_sig: Option<SecureSig>,
}
Represents a commit object, which contains a reference to the contents a that point in time, along with metadata about the commit.

Fields

parents: Vec<CommitId>

The parent commits of this commit. Commits typically have one parents, but they can have any number of parents. Only the root commit has no parents.

predecessors: Vec<CommitId>

The predecessor commits of this commit, i.e. commits that were rewritten to create this commit.

root_tree: Merge<TreeId>

The tree at the root directory in this commit.

conflict_labels: Merge<String>

If resolved, must be empty string. Otherwise, must have same number of terms as root_tree.

change_id: ChangeId

The change ID of this commit. This is a stable identifier that follows the commit when it’s rewritten.

description: String

The description (commit message).

author: Signature

The person/entity that authored this commit.

committer: Signature

The person/entity that committed this commit.

secure_sig: Option<SecureSig>

A cryptographic signature of this commit.