pub struct Tree { /* private fields */ }Expand description
A tree object, which represents a directory. It contains the direct entries
of the directory. Subdirectories are represented by the TreeValue::Tree
variant. The Tree object associated with the root directory thus
represents the entire repository at a given point in time.
The entries must be sorted (by RepoPathComponentBuf’s ordering) and must
not contain duplicate names.
Implementations
Sourceimpl Tree
impl Tree
Sourcepub fn from_sorted_entries(
entries: Vec<(RepoPathComponentBuf, TreeValue)>,
) -> Self
pub fn from_sorted_entries( entries: Vec<(RepoPathComponentBuf, TreeValue)>, ) -> Self
Creates a new Tree from the given entries. The entries must be sorted
by name and must not contain duplicate names.
Sourcepub fn names(&self) -> impl Iterator<Item = &RepoPathComponent>
pub fn names(&self) -> impl Iterator<Item = &RepoPathComponent>
Returns an iterator over the names of the entries in this tree.
Sourcepub fn entries(&self) -> TreeEntriesNonRecursiveIterator<'_> ⓘ
pub fn entries(&self) -> TreeEntriesNonRecursiveIterator<'_> ⓘ
Returns an iterator over the entries in this tree.
Sourcepub fn entry(&self, name: &RepoPathComponent) -> Option<TreeEntry<'_>>
pub fn entry(&self, name: &RepoPathComponent) -> Option<TreeEntry<'_>>
Returns the entry at the given basename, if it exists.
Sourcepub fn value(&self, name: &RepoPathComponent) -> Option<&TreeValue>
pub fn value(&self, name: &RepoPathComponent) -> Option<&TreeValue>
Returns the value at the given basename, if it exists.