ConflictLabels

Struct ConflictLabels 

pub struct ConflictLabels { /* private fields */ }
Optionally contains a set of labels for the terms of a conflict. Resolved merges cannot be labeled.

Implementations

Source

impl ConflictLabels

pub const fn unlabeled() -> Self

Create a ConflictLabels with no labels.

pub fn from_merge(labels: Merge<String>) -> Self

Create a ConflictLabels from a Merge<String>. If the merge is resolved, the labels will be discarded since resolved merges cannot have labels.

pub fn from_vec(labels: Vec<String>) -> Self

Create a ConflictLabels from a Vec<String>, with an empty vec representing no labels.

pub fn has_labels(&self) -> bool

Returns true if there are labels present.

pub fn num_sides(&self) -> Option<usize>

Returns the number of sides of the underlying merge if any terms have labels, or None if there are no labels.

pub fn as_merge(&self) -> &Merge<String>

Returns the underlying Merge<String>.

pub fn into_merge(self) -> Merge<String>

Extracts the underlying Merge<String>.

pub fn as_slice(&self) -> &[String]

Returns the conflict labels as a slice. If there are no labels, returns an empty slice.

pub fn get_add(&self, add_index: usize) -> Option<&str>

Get the label for a side at an index.

pub fn get_remove(&self, remove_index: usize) -> Option<&str>

Get the label for a base at an index.

pub fn simplify_with<T: PartialEq + Clone>( &self, merge: &Merge<T>, ) -> (Self, Merge<T>)

Simplify a merge with the same number of sides while preserving the conflict labels corresponding to each side of the merge.