pub enum ConvergeError {
Backend(BackendError),
Index(IndexError),
RevsetEvaluation(RevsetEvaluationError),
WalkPredecessors(WalkPredecessorsError),
IO(Error),
Other(Box<dyn Error + Send + Sync>),
}Expand description
Errors that can occur during converge.
Variants
Backend(BackendError)
A backend error occurred.
Index(IndexError)
An index error occurred.
RevsetEvaluation(RevsetEvaluationError)
An error occurred while evaluating the revset expression for finding divergent commits.
WalkPredecessors(WalkPredecessorsError)
An error occurred while traversing the evolution graph of the divergent commits.
IO(Error)
An IO error occurred.
Other(Box<dyn Error + Send + Sync>)
An unexpected error occurred.