TruncatedEvolutionGraph

Struct TruncatedEvolutionGraph 

pub struct TruncatedEvolutionGraph {
    pub flow_graph: FlowGraph<CommitId>,
    /* private fields */
}
The truncated evolution graph for a divergent change.

This is similar to the evolog graph, but truncated in the sense that it only contains commits that are for the given change-id, and only goes as far as the closest common dominator of the divergent commits.

Fields

flow_graph: FlowGraph<CommitId>

The evolution graph of the divergent commits, with edges X->Y if commit X is a predecessor of commit Y and both X and Y have the same divergent change-id. The graph is not necessarily a tree (commits may have multiple predecessors). The start node is the evolution fork point.

Implementations

Source

impl TruncatedEvolutionGraph

pub async fn new( repo: Arc<ReadonlyRepo>, divergent_commits: Vec<Commit>, ) -> Result<Self, ConvergeError>

Builds a truncated evolution graph for the given divergent commits, which are expected to all have the same change-id.

pub fn repo(&self) -> &Arc<ReadonlyRepo>

Returns the repo.

pub fn divergent_commits(&self) -> &Vec<Commit>

Returns the divergent commits.

pub fn divergent_commit_ids(&self) -> &Vec<CommitId>

Returns the commit ids of the divergent commits.

pub fn change_id(&self) -> &ChangeId

Returns the change-id of the divergent commits. All divergent commits are expected to have the same change-id.