pub enum CopyHistorySource {
Copy(RepoPathBuf),
Rename(RepoPathBuf),
Normal,
}Expand description
Describes the source of a CopyHistoryDiffTerm
Variants
Copy(RepoPathBuf)
The file was copied from a source at a different path
Rename(RepoPathBuf)
The file was renamed from a source at a different path
Normal
The source and target have the same path