diff

Function diff 

pub fn diff<'a, T>(inputs: impl IntoIterator<Item = &'a T>) -> Vec<DiffHunk<'a>>
where T: AsRef<[u8]> + 'a + ?Sized,
Diffs slices of bytes.

The returned diff hunks may be any length (may span many lines or may be only part of a line). This currently uses Histogram diff (or maybe something similar; I’m not sure I understood the algorithm correctly). It first diffs lines in the input and then refines the changed ranges at the word level.