FoldableExpression

Trait FoldableExpression 

pub trait FoldableExpression<'i>: Sized {
    // Required method
    fn fold<F>(self, folder: &mut F, span: Span<'i>) -> Result<Self, F::Error>
       where F: ExpressionFolder<'i, Self> + ?Sized;
}
Expression item that can be transformed recursively by using folder: F.

Required Methods

fn fold<F>(self, folder: &mut F, span: Span<'i>) -> Result<Self, F::Error>
where F: ExpressionFolder<'i, Self> + ?Sized,

Transforms self by applying the folder to inner items.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors