pub fn check_executable_bit_support(
path: impl AsRef<Path>,
) -> Result<bool, Error>Expand description
Whether changing executable bits is permitted on the filesystem of this directory, and whether attempting to flip one has an observable effect.