pub struct GitRefUpdate {
pub qualified_name: GitRefNameBuf,
pub expected_current_target: Option<CommitId>,
pub new_target: Option<CommitId>,
}Fields
qualified_name: GitRefNameBufexpected_current_target: Option<CommitId>Expected position on the remote or None if we expect the ref to not exist on the remote
This is sourced from the local remote-tracking branch.
new_target: Option<CommitId>Auto Trait Implementations
impl Freeze for GitRefUpdate
impl RefUnwindSafe for GitRefUpdate
impl Send for GitRefUpdate
impl Sync for GitRefUpdate
impl Unpin for GitRefUpdate
impl UnsafeUnpin for GitRefUpdate
impl UnwindSafe for GitRefUpdate