pub struct GitIgnoreFile { /* private fields */ }Expand description
Models the effective contents of multiple .gitignore files.
Implementations
Sourceimpl GitIgnoreFile
impl GitIgnoreFile
pub fn empty() -> Arc<Self>
Sourcepub fn chain(
self: &Arc<Self>,
prefix: &RepoPath,
ignore_path: &Path,
input: &[u8],
) -> Result<Arc<Self>, GitIgnoreError>
pub fn chain( self: &Arc<Self>, prefix: &RepoPath, ignore_path: &Path, input: &[u8], ) -> Result<Arc<Self>, GitIgnoreError>
Concatenates new .gitignore content at the prefix directory.
Sourcepub fn chain_with_file(
self: &Arc<Self>,
prefix: &RepoPath,
file: PathBuf,
) -> Result<Arc<Self>, GitIgnoreError>
pub fn chain_with_file( self: &Arc<Self>, prefix: &RepoPath, file: PathBuf, ) -> Result<Arc<Self>, GitIgnoreError>
Concatenates new .gitignore file at the prefix directory.
Sourcepub fn matches_file(&self, path: &RepoPath) -> bool
pub fn matches_file(&self, path: &RepoPath) -> bool
Returns whether the specified file path should be ignored.
This method does not directly define which files should not be tracked in the repository. Instead, it performs a simple matching against the last applicable .gitignore line.
This only performs exact matching; callers handle recursion of parent directories. Callers shouldn’t recursively match inside ignored directories, because all (untracked) child files should also be ignored; the exact matching logic won’t give correct results in that case.
Sourcepub fn matches_dir(&self, path: &RepoPath) -> bool
pub fn matches_dir(&self, path: &RepoPath) -> bool
Returns whether the specified directory path should be ignored.
See GitIgnoreFile::matches_file() for details.