Module graph

Module graph 

Structs

GraphEdge
TopoGroupedGraph
Graph iterator adapter builder to group topological branches.

Enums

GraphEdgeType

Functions

reverse_graph
Creates new graph in which nodes and edges are reversed.

Type Aliases

GraphNode
Node and edges pair of type N and ID respectively.