TopoGroupedGraph

Struct TopoGroupedGraph 

pub struct TopoGroupedGraph<N, ID, S, F> { /* private fields */ }
Graph iterator adapter builder to group topological branches.

Basic idea is DFS from the heads. At fork point, the other descendant branches will be visited. At merge point, the second (or the last) ancestor branch will be visited first. This is practically the same as Git.

If no branches are prioritized, the branch containing the first commit in the input iterator will be emitted first. It is often the working-copy ancestor branch. The other head branches won’t be enqueued eagerly, and will be emitted as late as possible.

Implementations

Source

impl<N, ID, E, S, F> TopoGroupedGraph<N, ID, S, F>
where ID: Clone + Hash + Eq + Unpin, S: Stream<Item = Result<GraphNode<N, ID>, E>> + Unpin, F: Fn(&N) -> &ID + Unpin,

pub fn new(input_stream: S, as_id: F) -> Self

Wraps the given iterator to group topological branches. The input iterator must be topologically ordered.

pub fn prioritize_branch(&mut self, id: ID)

Makes the branch containing the specified node be emitted earlier than the others.

The id usually points to a head node, but this isn’t a requirement. If the specified node isn’t a head, all preceding nodes will be queued.

The specified node must exist in the input iterator. If it didn’t, the iterator would panic.

pub fn stream(self) -> impl Stream<Item = Result<GraphNode<N, ID>, E>>

Make a stream based on the input stream and the optional prioritized branches.