pub enum FindDominatorValueError<E> {
ValueFnError(E),
DominatorFinderError(DominatorFinderError),
}Expand description
Errors that can occur while finding a dominator value (i.e. a dominator in a value flow graph).
Variants
ValueFnError(E)
An error occurred while computing the value of a node.
DominatorFinderError(DominatorFinderError)
An error occurred while finding the dominator.