pub struct DominatorFinder<'a, N> { /* private fields */ }Expand description
Calculates the dominators in a flow graph. Also has a method for finding the closest common dominator of a set of nodes.
Implementations
Sourceimpl<'a, N> DominatorFinder<'a, N>
impl<'a, N> DominatorFinder<'a, N>
Sourcepub fn calculate(
flow_graph: &'a FlowGraph<N>,
) -> Result<Self, DominatorFinderError>
pub fn calculate( flow_graph: &'a FlowGraph<N>, ) -> Result<Self, DominatorFinderError>
Constructs a new DominatorFinder. Returns an error if the flow graph is invalid: e.g. if some node is unreachable from the start node.
Sourcepub fn get_immediate_dominators(&self) -> HashMap<N, N>
pub fn get_immediate_dominators(&self) -> HashMap<N, N>
Returns a map from each node to its immediate dominator. NOTE: the immediate dominator of the start node is itself.
Sourcepub fn find_closest_common_dominator<NI>(
&self,
target_set: NI,
) -> Result<N, DominatorFinderError>where
NI: IntoIterator<Item = N>,
pub fn find_closest_common_dominator<NI>(
&self,
target_set: NI,
) -> Result<N, DominatorFinderError>where
NI: IntoIterator<Item = N>,
Finds the closest common dominator for the given flow graph and set of nodes S (target_set).