pub struct FlowGraph<N>{
pub graph: SimpleDirectedGraph<N>,
pub start_node: N,
}Expand description
A FlowGraph is a directed graph with a designated start node.
Any node in the graph can be the start node. There are no reachability requirements whatsoever: some nodes may be unreachable from the start node, the start node could have incoming edges, the graph could be disconnected, etc.
Fields
graph: SimpleDirectedGraph<N>The graph.
start_node: NThe start node.
Implementations
Sourceimpl<N> FlowGraph<N>
impl<N> FlowGraph<N>
Sourcepub fn new(graph: SimpleDirectedGraph<N>, start_node: N) -> Self
pub fn new(graph: SimpleDirectedGraph<N>, start_node: N) -> Self
Constructs a new FlowGraph.
Sourcepub fn create_value_flow_graph<'a, V>(
&self,
node_values: &'a HashMap<N, V>,
) -> FlowGraph<&'a V>
pub fn create_value_flow_graph<'a, V>( &self, node_values: &'a HashMap<N, V>, ) -> FlowGraph<&'a V>
Creates a flow graph of values from a flow graph of nodes.
More precisely, let G be a FlowGraph of nodes with start node S. The value flow graph G’ is a FlowGraph derived from G. Let v(g) be the result of applying value_fn to g. The nodes of G’ are the set of values v(g), for all g in G. For each edge g1->g2 in G, there is a corresponding edge v(g1)->v(g2) in G’. The start node in G’ is v(S).
Returns an error if any value_fn invocation fails.
Sourcepub async fn find_dominator_value<V, VF, E>(
&self,
final_nodes: &[N],
value_fn: VF,
) -> Result<V, FindDominatorValueError<E>>
pub async fn find_dominator_value<V, VF, E>( &self, final_nodes: &[N], value_fn: VF, ) -> Result<V, FindDominatorValueError<E>>
Constructs a value flow graph from the given flow graph and value
function, and finds the closest common dominator value for the
values of the final nodes. Returns an error if value_fn returns an
error for any node in the flow graph. final_nodes must not be empty.