SimpleDirectedGraph

Struct SimpleDirectedGraph 

pub struct SimpleDirectedGraph<N>
where N: Clone + Eq + Hash,
{ /* private fields */ }
An immutable directed graph with nodes of type N and a minimal interface for iterating over nodes and their adjacent nodes.

Implementations

Source

impl<N> SimpleDirectedGraph<N>
where N: Clone + Eq + Hash,

pub fn new<EI>(edges: EI) -> Self
where EI: IntoIterator<Item = (N, N)>,

Constructs a new SimpleDirectedGraph from a list of edges.

pub fn nodes(&self) -> impl Iterator<Item = &N>

Returns the nodes in this graph.

pub fn num_nodes(&self) -> usize

Returns the nodes in this graph.

pub fn edges(&self) -> impl Iterator<Item = (&N, &N)>

Returns the edges in this graph.

pub fn adjacent_nodes( &self, node: &N, ) -> Option<impl DoubleEndedIterator<Item = &N>>

Returns the adjacent nodes for the given node, or None if the node is not in the graph.

pub fn contains_node(&self, node: &N) -> bool

Returns true if this graph contains the given node.

pub fn get_postorder<'a>(&'a self, start_node: &'a N) -> Vec<&'a N>

Returns a postorder traversal of the nodes in this graph starting from the given node.