pub struct ValueCache<N, V, VF> { /* private fields */ }Expand description
Helper struct for constructing a value flow graph. It caches the results of applying value_fn to nodes, and also keeps track of the mapping from values to nodes and nodes to values.
Implementations
Sourceimpl<N, V, VF, E> ValueCache<N, V, VF>
impl<N, V, VF, E> ValueCache<N, V, VF>
Sourcepub fn new(value_fn: VF) -> Self
pub fn new(value_fn: VF) -> Self
Creates a new ValueCache that uses the given function to get values.
Sourcepub async fn get_value(&mut self, node: &N) -> Result<Rc<V>, E>
pub async fn get_value(&mut self, node: &N) -> Result<Rc<V>, E>
Returns the value for the given node, computing it if it is not already cached.
Sourcepub fn get_nodes_for_value(&self, value: &Rc<V>) -> Option<&Vec<N>>
pub fn get_nodes_for_value(&self, value: &Rc<V>) -> Option<&Vec<N>>
Returns the nodes that have the given value.