pub struct Merge<T> { /* private fields */ }Expand description
A generic representation of merged values.
There is exactly one more adds() than removes(). When interpreted as a
series of diffs, the merge’s (i+1)-st add is matched with the i-th
remove. The zeroth add is considered a diff from the non-existent state.
Implementations
Sourceimpl<T> Merge<T>
impl<T> Merge<T>
Sourcepub fn from_vec(values: impl Into<SmallVec<[T; 1]>>) -> Merge<T>
pub fn from_vec(values: impl Into<SmallVec<[T; 1]>>) -> Merge<T>
Creates a Merge from the given values, in which positive and negative
terms alternate.
Sourcepub fn from_removes_adds(
removes: impl IntoIterator<Item = T>,
adds: impl IntoIterator<Item = T>,
) -> Merge<T>
pub fn from_removes_adds( removes: impl IntoIterator<Item = T>, adds: impl IntoIterator<Item = T>, ) -> Merge<T>
Creates a new merge object from the given removes and adds.
Sourcepub fn from_diffs(
first_side: T,
diffs: impl IntoIterator<Item = Diff<T>>,
) -> Merge<T>
pub fn from_diffs( first_side: T, diffs: impl IntoIterator<Item = Diff<T>>, ) -> Merge<T>
Creates a Merge from a first side and a series of diffs to apply to
that side.
Sourcepub fn repeated(value: T, num_sides: usize) -> Merge<T>where
T: Clone,
pub fn repeated(value: T, num_sides: usize) -> Merge<T>where
T: Clone,
Creates a Merge by repeating a single value.
Sourcepub fn from_legacy_form(
removes: impl IntoIterator<Item = T>,
adds: impl IntoIterator<Item = T>,
) -> Merge<Option<T>>
pub fn from_legacy_form( removes: impl IntoIterator<Item = T>, adds: impl IntoIterator<Item = T>, ) -> Merge<Option<T>>
Create a Merge from a removes and adds, padding with None to
make sure that there is exactly one more adds than removes.
Sourcepub fn removes(&self) -> impl ExactSizeIterator
pub fn removes(&self) -> impl ExactSizeIterator
The removed values, also called negative terms.
Sourcepub fn adds(&self) -> impl ExactSizeIterator
pub fn adds(&self) -> impl ExactSizeIterator
The added values, also called positive terms.
Sourcepub fn into_removes_adds(
self,
) -> (impl ExactSizeIterator, impl ExactSizeIterator)
pub fn into_removes_adds( self, ) -> (impl ExactSizeIterator, impl ExactSizeIterator)
Return the removed values and added values and take the ownership.
Sourcepub fn get_remove(&self, index: usize) -> Option<&T>
pub fn get_remove(&self, index: usize) -> Option<&T>
Returns the index-th removed value, which is considered belonging to
the index-th diff pair.
Sourcepub fn get_add(&self, index: usize) -> Option<&T>
pub fn get_add(&self, index: usize) -> Option<&T>
Returns the index-th added value, which is considered belonging to the
index-1-th diff pair. The zeroth add is a diff from the non-existent
state.
Sourcepub fn swap_remove(&mut self, remove_index: usize, add_index: usize) -> (T, T)
pub fn swap_remove(&mut self, remove_index: usize, add_index: usize) -> (T, T)
Removes the specified “removed”/“added” values. The removed slots are replaced by the last “removed”/“added” values.
Sourcepub fn is_resolved(&self) -> bool
pub fn is_resolved(&self) -> bool
Whether this merge is resolved. Does not resolve trivial merges.
Sourcepub fn as_resolved(&self) -> Option<&T>
pub fn as_resolved(&self) -> Option<&T>
Returns the resolved value, if this merge is resolved. Does not resolve trivial merges.
Sourcepub fn into_resolved(self) -> Result<T, Merge<T>>
pub fn into_resolved(self) -> Result<T, Merge<T>>
Returns the resolved value, if this merge is resolved. Otherwise returns
the merge itself as an Err. Does not resolve trivial merges.
Sourcepub fn simplify(&self) -> Merge<T>
pub fn simplify(&self) -> Merge<T>
Simplify the merge by joining diffs like A->B and B->C into A->C. Also drops trivial diffs like A->A.
Sourcepub fn simplify_by<'a, U>(&'a self, f: impl FnMut(&'a T) -> U) -> Merge<T>
pub fn simplify_by<'a, U>(&'a self, f: impl FnMut(&'a T) -> U) -> Merge<T>
Simplify the merge, using a function to choose which values to compare.
Sourcepub fn update_from_simplified(self, simplified: Merge<T>) -> Merge<T>where
T: PartialEq,
pub fn update_from_simplified(self, simplified: Merge<T>) -> Merge<T>where
T: PartialEq,
Updates the merge based on the given simplified merge.
Sourcepub fn resolve_trivial(&self, same_change: SameChange) -> Option<&T>
pub fn resolve_trivial(&self, same_change: SameChange) -> Option<&T>
If this merge can be trivially resolved, returns the value it resolves to.
Sourcepub fn pad_to(&mut self, num_sides: usize, value: &T)where
T: Clone,
pub fn pad_to(&mut self, num_sides: usize, value: &T)where
T: Clone,
Pads this merge with to the specified number of sides with the specified value. No-op if the requested size is not larger than the current size.
Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice containing the terms. The items will alternate between positive and negative terms, starting with positive (since there’s one more of those).
Sourcepub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter(&self) -> Iter<'_, T> ⓘ
Returns an iterator over references to the terms. The items will alternate between positive and negative terms, starting with positive (since there’s one more of those).
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘ
A version of Merge::iter() that iterates over mutable references.
Sourcepub fn map<'a, U>(&'a self, f: impl FnMut(&'a T) -> U) -> Merge<U>
pub fn map<'a, U>(&'a self, f: impl FnMut(&'a T) -> U) -> Merge<U>
Creates a new merge by applying f to each remove and add.
Sourcepub fn into_map<U>(self, f: impl FnMut(T) -> U) -> Merge<U>
pub fn into_map<U>(self, f: impl FnMut(T) -> U) -> Merge<U>
Creates a new merge by applying f to each remove and add, consuming
self.
Sourcepub fn try_map<'a, U, E>(
&'a self,
f: impl FnMut(&'a T) -> Result<U, E>,
) -> Result<Merge<U>, E>
pub fn try_map<'a, U, E>( &'a self, f: impl FnMut(&'a T) -> Result<U, E>, ) -> Result<Merge<U>, E>
Creates a new merge by applying f to each remove and add, returning
Err if f returns Err for any of them.
Sourceimpl<T> Merge<Option<T>>
impl<T> Merge<Option<T>>
Sourcepub fn normal(value: T) -> Merge<Option<T>>
pub fn normal(value: T) -> Merge<Option<T>>
Creates a resolved merge with a value of Some(value).
Sourcepub fn is_present(&self) -> bool
pub fn is_present(&self) -> bool
The opposite of is_absent().
Sourcepub fn as_normal(&self) -> Option<&T>
pub fn as_normal(&self) -> Option<&T>
Returns the value if this is present and non-conflicting.
Sourcepub fn into_legacy_form(self) -> (Vec<T>, Vec<T>)
pub fn into_legacy_form(self) -> (Vec<T>, Vec<T>)
Creates lists of removes and adds from a Merge by dropping
None values. Note that the conversion is lossy: the order of None
values is not preserved when converting back to a Merge.