pub struct RepoPathTree<V> { /* private fields */ }Expand description
Tree that maps RepoPath to value of type V.
Implementations
Sourceimpl<V> RepoPathTree<V>
impl<V> RepoPathTree<V>
Sourcepub fn value_mut(&mut self) -> &mut V
pub fn value_mut(&mut self) -> &mut V
Mutable reference to the value associated with this path.
Sourcepub fn children(
&self,
) -> impl Iterator<Item = (&RepoPathComponent, &RepoPathTree<V>)>
pub fn children( &self, ) -> impl Iterator<Item = (&RepoPathComponent, &RepoPathTree<V>)>
The immediate children of this node.
Sourcepub fn has_children(&self) -> bool
pub fn has_children(&self) -> bool
Whether this node has any children.
Sourcepub fn add(&mut self, path: &RepoPath) -> &mut RepoPathTree<V>where
V: Default,
pub fn add(&mut self, path: &RepoPath) -> &mut RepoPathTree<V>where
V: Default,
Add a path to the tree. Normally called on the root tree.
Sourcepub fn get(&self, path: &RepoPath) -> Option<&RepoPathTree<V>>
pub fn get(&self, path: &RepoPath) -> Option<&RepoPathTree<V>>
Get a reference to the node for the given path, if it exists in the
tree.