Module settings

Module settings 

Structs

HumanByteSize
A size in bytes optionally formatted/serialized with binary prefixes
JJRng
This Rng uses interior mutability to allow generating random values using an immutable reference. It also fixes a specific seedable RNG for reproducibility.
RemoteSettings
SignSettings
Commit signing settings, describes how to and if to sign commits.
UserSettings

Type Aliases

RemoteSettingsMap