Module ui_path

Module ui_path 

Utilities for converting between RepoPaths and plain strings as displayed to the user (e.g. relative to CWD).

Structs

FsPathParseError
An error which occurs when we’re parsing paths.

Enums

RepoPathUiConverter
Converts RepoPaths to and from plain strings as displayed to the user (e.g. relative to CWD).
UiPathParseError
An error from RepoPathUiConverter::parse_file_path.

Functions

parse_fs_path
Parses an input path into a RepoPathBuf relative to base.