pub struct ConflictLabels { /* private fields */ }Expand description
Optionally contains a set of labels for the terms of a conflict. Resolved merges cannot be labeled.
Implementations
Sourceimpl ConflictLabels
impl ConflictLabels
Sourcepub fn from_merge(labels: Merge<String>) -> Self
pub fn from_merge(labels: Merge<String>) -> Self
Create a ConflictLabels from a Merge<String>. If the merge is
resolved, the labels will be discarded since resolved merges cannot have
labels.
Sourcepub fn from_vec(labels: Vec<String>) -> Self
pub fn from_vec(labels: Vec<String>) -> Self
Create a ConflictLabels from a Vec<String>, with an empty vec
representing no labels.
Sourcepub fn has_labels(&self) -> bool
pub fn has_labels(&self) -> bool
Returns true if there are labels present.
Sourcepub fn num_sides(&self) -> Option<usize>
pub fn num_sides(&self) -> Option<usize>
Returns the number of sides of the underlying merge if any terms have
labels, or None if there are no labels.
Sourcepub fn into_merge(self) -> Merge<String>
pub fn into_merge(self) -> Merge<String>
Extracts the underlying Merge<String>.
Sourcepub fn as_slice(&self) -> &[String]
pub fn as_slice(&self) -> &[String]
Returns the conflict labels as a slice. If there are no labels, returns an empty slice.
Sourcepub fn get_remove(&self, remove_index: usize) -> Option<&str>
pub fn get_remove(&self, remove_index: usize) -> Option<&str>
Get the label for a base at an index.