pub struct TruncatedEvolutionGraph {
pub flow_graph: FlowGraph<CommitId>,
/* private fields */
}Expand description
The truncated evolution graph for a divergent change.
This is similar to the evolog graph, but truncated in the sense that it only contains commits that are for the given change-id, and only goes as far as the closest common dominator of the divergent commits.
Fields
flow_graph: FlowGraph<CommitId>The evolution graph of the divergent commits, with edges X->Y if commit X is a predecessor of commit Y and both X and Y have the same divergent change-id. The graph is not necessarily a tree (commits may have multiple predecessors). The start node is the evolution fork point.
Implementations
Sourceimpl TruncatedEvolutionGraph
impl TruncatedEvolutionGraph
Sourcepub async fn new(
repo: Arc<ReadonlyRepo>,
divergent_commits: Vec<Commit>,
) -> Result<Self, ConvergeError>
pub async fn new( repo: Arc<ReadonlyRepo>, divergent_commits: Vec<Commit>, ) -> Result<Self, ConvergeError>
Builds a truncated evolution graph for the given divergent commits, which are expected to all have the same change-id.
Sourcepub fn repo(&self) -> &Arc<ReadonlyRepo>
pub fn repo(&self) -> &Arc<ReadonlyRepo>
Returns the repo.
Sourcepub fn divergent_commits(&self) -> &Vec<Commit>
pub fn divergent_commits(&self) -> &Vec<Commit>
Returns the divergent commits.
Sourcepub fn divergent_commit_ids(&self) -> &Vec<CommitId>
pub fn divergent_commit_ids(&self) -> &Vec<CommitId>
Returns the commit ids of the divergent commits.