API for transforming file content, for example to apply formatting, and propagate those changes across revisions.
Structs
- File
ToFix - Represents a file whose content may be transformed by a FileFixer.
- FixSummary
- Aggregate information about the outcome of the file fixer.
- Format
Range - A formattable range of lines or bytes.
- Parallel
File Fixer - A FileFixer that applies fix_fn to each file, in parallel.
Enums
- FixError
- Error fixing files.
- Regions
ToFormat - Representation of different ranges formatters can use to emit diff ranges.
Traits
- File
Fixer - Fixes a set of files.
Functions
- compute_
changed_ ranges - Computes the 1-based line ranges in
currentthat are different frombase. The ranges produced can be empty. - compute_
file_ line_ count - Computes the number of lines in a byte slice (i.e. a file).
- fix_
files - Updates files with formatting fixes or other changes, using the given FileFixer.
- get_
base_ commit_ map - Given a vector of commits, determine the base commit(s) for each of the commits in the vector.
Type Aliases
- Line
Range - A line range (1-based, inclusive [first, last]).