pub async fn get_base_commit_map(
commits: &[Commit],
) -> Result<HashMap<CommitId, IndexSet<CommitId>>, FixError>Expand description
Given a vector of commits, determine the base commit(s) for each of the commits in the vector.
Notes:
commitsmust be sorted in reverse topological order (children before parents).- The returned base commits are the closest ancestors for each commit that
are not in
commits. They may include ancestors of other base commits.
The current commit will diff against the base commit(s) to determine the
modified files that need to be jj fixed. We also use these base commits to
compute modified lines by diffing the file content in the current commit
against the file content in the base commit(s).
This is public only for testing purposes.