pub struct SimpleDirectedGraph<N>{ /* private fields */ }Expand description
An immutable directed graph with nodes of type N and a minimal interface for iterating over nodes and their adjacent nodes.
Implementations
Sourceimpl<N> SimpleDirectedGraph<N>
impl<N> SimpleDirectedGraph<N>
Sourcepub fn new<EI>(edges: EI) -> Selfwhere
EI: IntoIterator<Item = (N, N)>,
pub fn new<EI>(edges: EI) -> Selfwhere
EI: IntoIterator<Item = (N, N)>,
Constructs a new SimpleDirectedGraph from a list of edges.
Sourcepub fn adjacent_nodes(
&self,
node: &N,
) -> Option<impl DoubleEndedIterator<Item = &N>>
pub fn adjacent_nodes( &self, node: &N, ) -> Option<impl DoubleEndedIterator<Item = &N>>
Returns the adjacent nodes for the given node, or None if the node is not in the graph.
Sourcepub fn contains_node(&self, node: &N) -> bool
pub fn contains_node(&self, node: &N) -> bool
Returns true if this graph contains the given node.
Sourcepub fn get_postorder<'a>(&'a self, start_node: &'a N) -> Vec<&'a N>
pub fn get_postorder<'a>(&'a self, start_node: &'a N) -> Vec<&'a N>
Returns a postorder traversal of the nodes in this graph starting from the given node.