pub trait ObjectId {
// Required methods
fn object_type(&self) -> String;
fn as_bytes(&self) -> &[u8] ⓘ;
fn to_bytes(&self) -> Vec<u8> ⓘ;
fn hex(&self) -> String;
}Expand description
An identifier for an object, such as a commit or a tree, usually the output of a hash function.
Required Methods
Sourcefn object_type(&self) -> String
fn object_type(&self) -> String
A lowercase name identifying the type of object (e.g. “commit”).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".