pub fn parse_fs_path(
cwd: &Path,
base: &Path,
input: impl AsRef<Path>,
) -> Result<RepoPathBuf, FsPathParseError>Expand description
Parses an input path into a RepoPathBuf relative to base.
The cwd and base paths are supposed to be absolute and normalized in
the same manner. The input path may be either relative to cwd or
absolute.